@@ -5,7 +5,7 @@
 %%% Created : 1 May 2013 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -49,14 +49,7 @@
 %% @end
 %%--------------------------------------------------------------------
 start(_StartType, _StartArgs) ->
-    case {fxml:load_nif(), fxml_stream:load_nif()} of
-        {ok, ok} ->
-            fxml_sup:start_link();
-        {{error,_} = E1, _} ->
-            E1;
-        {_, {error,_} = E2} ->
-            E2
-    end.
+    fxml_sup:start_link().
 
 %%--------------------------------------------------------------------
 %% @private
