@@ -5,7 +5,7 @@
 %%% Created : 17 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -27,6 +27,8 @@
 
 -compile(no_native).
 
+-on_load(init/0).
+
 -export([new/1, new/2, new/3, parse/2, close/1, reset/1,
 	 change_callback_pid/2, parse_element/1]).
 
@@ -53,6 +55,9 @@
 
 -export_type([xml_stream_state/0, xml_stream_el/0]).
 
+init() ->
+    ok = load_nif().
+
 load_nif() ->
     SOPath = p1_nif_utils:get_so_path(?MODULE, [fast_xml], "fxml_stream"),
     load_nif(SOPath).
