@@ -5,7 +5,7 @@
 %%% Created : 17 Dec 2013 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -39,8 +39,10 @@ close(State) ->
     ?assertEqual(true, fxml_stream:close(State)).
 
 start_test() ->
-    ?assertEqual(ok, fxml:load_nif(p1_nif_utils:get_so_path(fxml, [], "fxml"))),
-    ?assertEqual(ok, fxml_stream:load_nif(p1_nif_utils:get_so_path(fxml_stream, [], "fxml_stream"))).
+    ?assertMatch({ok, _}, application:ensure_all_started(fast_xml)),
+    ?assertMatch(ok, application:stop(fast_xml)),
+    ?assertMatch({ok, _}, application:ensure_all_started(fast_xml)),
+    ?assertMatch(ok, application:stop(fast_xml)).
 
 tag_test() ->
     ?assertEqual(#xmlel{name = <<"root">>},
